summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/LB_PropertyManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/LB_PropertyManager.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/LB_PropertyManager.h79
1 files changed, 40 insertions, 39 deletions
diff --git a/TAO/orbsvcs/orbsvcs/LB_PropertyManager.h b/TAO/orbsvcs/orbsvcs/LB_PropertyManager.h
index 06260ad4a49..4ed24c6b7d9 100644
--- a/TAO/orbsvcs/orbsvcs/LB_PropertyManager.h
+++ b/TAO/orbsvcs/orbsvcs/LB_PropertyManager.h
@@ -24,6 +24,7 @@
#include "ace/Functor.h"
#include "ace/Hash_Map_Manager_T.h"
+#include "orbsvcs/PortableGroupC.h"
#include "orbsvcs/LoadBalancingC.h"
@@ -34,7 +35,7 @@ class TAO_LB_ObjectGroup_Map;
/**
* @class TAO_LB_PropertyManager
*
* @brief Class that implements the LoadBalancing::PropertyManager
* interface.
*
* Only the default and type-specific properties are housed in this
@@ -44,7 +45,7 @@ class TAO_LB_ObjectGroup_Map;
* PropertyManager is still used to manage those properties.
*/
class TAO_LB_PropertyManager
- : public virtual LoadBalancing::PropertyManager
+ : public virtual PortableGroup::PropertyManager
{
public:
@@ -52,47 +53,47 @@ public:
TAO_LB_PropertyManager (TAO_LB_ObjectGroup_Map &object_group_map);
/**
- * @name TAO_LoadBalancer::PropertyManager methods
+ * @name PortableGroup::PropertyManager methods
*/
//@{
/// Set the default properties to be used by all object groups.
virtual void set_default_properties (
- const LoadBalancing::Properties & props,
+ const PortableGroup::Properties & props,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty));
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty));
/// Get the default properties used by all object groups.
- virtual LoadBalancing::Properties * get_default_properties (
+ virtual PortableGroup::Properties * get_default_properties (
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException));
/// Remove default properties.
virtual void remove_default_properties (
- const LoadBalancing::Properties & props,
+ const PortableGroup::Properties & props,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty));
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty));
/// Set properties associated with a given Replica type. These
/// properties override the default properties.
virtual void set_type_properties (
const char * type_id,
- const LoadBalancing::Properties & overrides,
+ const PortableGroup::Properties & overrides,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty));
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty));
/**
* Return the properties associated with a give Replica type. These
* properties include the type-specific properties in use, in
* addition to the default properties that were not overridden.
*/
- virtual LoadBalancing::Properties * get_type_properties (
+ virtual PortableGroup::Properties * get_type_properties (
const char * type_id,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException));
@@ -100,11 +101,11 @@ public:
/// Remove the given properties associated with the Replica type ID.
virtual void remove_type_properties (
const char * type_id,
- const LoadBalancing::Properties & props,
+ const PortableGroup::Properties & props,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty));
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty));
/**
* Dynamically set the properties associated with a given object
@@ -113,13 +114,13 @@ public:
* properties.
*/
virtual void set_properties_dynamically (
- LoadBalancing::ObjectGroup_ptr object_group,
- const LoadBalancing::Properties & overrides,
+ PortableGroup::ObjectGroup_ptr object_group,
+ const PortableGroup::Properties & overrides,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::ObjectGroupNotFound,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty));
+ PortableGroup::ObjectGroupNotFound,
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty));
/**
* Return the properties currently in use by the given object
@@ -128,21 +129,21 @@ public:
* were used when the replica was created, and default properties
* that weren't overridden.
*/
- virtual LoadBalancing::Properties * get_properties (
- LoadBalancing::ObjectGroup_ptr object_group,
+ virtual PortableGroup::Properties * get_properties (
+ PortableGroup::ObjectGroup_ptr object_group,
CORBA::Environment &ACE_TRY_ENV = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::ObjectGroupNotFound));
+ PortableGroup::ObjectGroupNotFound));
//@}
/// Verify that the given properties are valid and/or supported by
/// the Load Balancer.
- void validate_properties (const LoadBalancing::Properties &props,
+ void validate_properties (const PortableGroup::Properties &props,
CORBA::Environment &ACE_TRY_ENV)
- ACE_THROW_SPEC ((LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty));
+ ACE_THROW_SPEC ((PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty));
/**
* @name TAO-specific Load Balancing PropertyManager Helper Methods
@@ -155,7 +156,7 @@ public:
//@{
/// Return the membership style for the given object group.
- LoadBalancing::MembershipStyle membership_style (
+ PortableGroup::MembershipStyleValue membership_style (
CORBA::Object_ptr object_group) const;
/// Return the load monitoring style for the given object group.
@@ -169,21 +170,21 @@ public:
/// Return the initial number of replicas for the given object
/// group.
- LoadBalancing::InitialNumberReplicas
- initial_number_replicas (const char *type_id,
- const LoadBalancing::Criteria &the_criteria,
- CORBA::Environment &ACE_TRY_ENV) const;
+ PortableGroup::InitialNumberMembersValue
+ initial_number_members (const char *type_id,
+ const PortableGroup::Criteria &the_criteria,
+ CORBA::Environment &ACE_TRY_ENV) const;
/// Return the minimum number of replicas for the given object
/// group.
- LoadBalancing::MinimumNumberReplicas
- minimum_number_replicas (CORBA::Object_ptr object_group) const;
+ PortableGroup::MinimumNumberMembersValue
+ minimum_number_members (CORBA::Object_ptr object_group) const;
/// Return the sequence FactoryInfos associated with the given
/// object group.
- LoadBalancing::FactoryInfos *
+ PortableGroup::FactoryInfos *
factory_infos (const char *type_id,
- const LoadBalancing::Criteria &the_criteria,
+ const PortableGroup::Criteria &the_criteria,
CORBA::Environment &ACE_TRY_ENV) const;
//@}
@@ -191,7 +192,7 @@ public:
/// Type-specific property hash map.
typedef ACE_Hash_Map_Manager_Ex<
const char *,
- LoadBalancing::Properties,
+ PortableGroup::Properties,
ACE_Hash<const char *>,
ACE_Equal_To<const char *>,
ACE_Null_Mutex> Type_Prop_Table;
@@ -202,7 +203,7 @@ private:
TAO_LB_ObjectGroup_Map &object_group_map_;
/// Default properties.
- LoadBalancing::Properties default_properties_;
+ PortableGroup::Properties default_properties_;
/// Table of type-specific object group properties.
Type_Prop_Table type_properties_;
@@ -34,7 +35,7 @@ class TAO_LB_ObjectGroup_Map;
* @class TAO_LB_PropertyManager
*
- * @brief Class that implements the LoadBalancing::PropertyManager
+ * @brief Class that implements the PortableGroup::PropertyManager
* interface.
*